pub struct SiftStreamMetrics { /* private fields */ }Expand description
Primary metrics collection struct for sift stream operations.
This struct is managed internally and users should never need to create this, instead using the crate::SiftStreamBuilder
Implementations
Sourceimpl SiftStreamMetrics
impl SiftStreamMetrics
Sourcepub fn new() -> SiftStreamMetrics
pub fn new() -> SiftStreamMetrics
Creates a new SiftStreamMetrics instance with current timestamp. Users should never need to call this and should instead use crate::SiftStreamBuilder