pub struct IngestionConfigForm {
pub asset_name: String,
pub client_key: String,
pub flows: Vec<FlowConfig>,
}Expand description
A form to create a new ingestion config or retrieve an existing ingestion config based on the
client_key provided. The client_key is an arbitrary user-sourced identifier that is
expected to be unique across the user’s organization; it’s used to uniquely identify a
particular ingestion config which defines the schema of an asset’s telemetry. See the
top-level documentation for further details.
Fields
asset_name: Stringclient_key: Stringflows: Vec<FlowConfig>Trait Implementations
Sourceimpl Clone for IngestionConfigForm
impl Clone for IngestionConfigForm
Sourcefn clone(&self) -> IngestionConfigForm
fn clone(&self) -> IngestionConfigForm
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for IngestionConfigForm
impl RefUnwindSafe for IngestionConfigForm
impl Send for IngestionConfigForm
impl Sync for IngestionConfigForm
impl Unpin for IngestionConfigForm
impl UnwindSafe for IngestionConfigForm