pub struct ChannelEnum(pub u32);Expand description
Represents a specific enumeration value for an enum channel.
Enum channels use numeric values to represent discrete states. This wrapper type makes it clear when a value represents an enum variant.
Example
use sift_stream::{ChannelValue, ChannelEnum};
let enum_value = ChannelValue::new("state", ChannelEnum(0));Tuple Fields
0: u32Trait Implementations
Sourceimpl Debug for ChannelEnum
impl Debug for ChannelEnum
Sourceimpl From<ChannelEnum> for Value
impl From<ChannelEnum> for Value
Sourcefn from(value: ChannelEnum) -> Self
fn from(value: ChannelEnum) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for ChannelEnum
impl PartialEq for ChannelEnum
Sourcefn eq(&self, other: &ChannelEnum) -> bool
fn eq(&self, other: &ChannelEnum) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ChannelEnum