pub struct IngestionConfigEncoder { /* private fields */ }Implementations
Sourceimpl IngestionConfigEncoder
impl IngestionConfigEncoder
Sourcepub async fn add_new_flows(&mut self, flow_configs: &[FlowConfig]) -> Result<()>
pub async fn add_new_flows(&mut self, flow_configs: &[FlowConfig]) -> Result<()>
Modify the existing ingestion config by adding new flows that weren’t accounted for during initialization. This will register the flows with Sift.
ErrorKind::AlreadyExistsError from any flow creation is treated as success: a
concurrent SiftStream instance may have won the race to create that flow.
Sourcepub fn get_flows(&self) -> HashMap<String, FlowDescriptor<String>>
pub fn get_flows(&self) -> HashMap<String, FlowDescriptor<String>>
Get a copy of the current flow descriptors known to SiftStream as a HashMap keyed to the flow name.
Sourcepub fn get_flow_descriptor(
&self,
flow_name: &str,
) -> Result<FlowDescriptor<String>>
pub fn get_flow_descriptor( &self, flow_name: &str, ) -> Result<FlowDescriptor<String>>
Get the flow descriptor for a given flow name.