SiftStream

Struct SiftStream 

pub struct SiftStream<E, T = LiveStreaming> { /* private fields */ }
SiftStream is a smart wrapper over an actual gRPC stream that makes it robust and more ergonomic to work with. Some additional behaviors that SiftStream supports are:

  • Checkpointing
  • Retries (disabled by default)
  • Backups (disabled by default)
  • Tracing and ingestion metrics

To initialize a SiftStream users will use builder::SiftStreamBuilder. Refer to the crate-level documentation for further details and examples.

Implementations

Source

impl<E, T> SiftStream<E, T>
where E: Encoder + MetricsSnapshot, T: Transport<Encoder = E>,

pub fn get_metrics_snapshot(&self) -> SiftStreamMetricsSnapshot

Available on crate feature metrics-unstable only.

Retrieve a snapshot of the current metrics for this stream.

pub async fn attach_run(&mut self, run_selector: RunSelector) -> Result<()>

Attach a run to the stream. Any data provided through SiftStream::send after return of this function will be associated with the run.

pub fn detach_run(&mut self)

Detach the run, if any, associated with the stream. Any data provided through SiftStream::send after this function is called will not be associated with a run.

pub fn run(&self) -> Option<&Run>

Retrieves the attached run if it exists.

pub async fn send<M>(&mut self, message: M) -> Result<()>
where M: Encodeable<Encoder = E, Output = <T as Transport>::Message> + Send + Sync,

The entry-point to send actual telemetry to Sift in the form of [Flow]s.

pub async fn send_requests<I>(&mut self, requests: I) -> Result<()>
where I: IntoIterator<Item = <T as Transport>::Message> + Send, I::IntoIter: Send,

This method offers a way to send data in a manner that’s identical to the raw gRPC service for ingestion-config based streaming.

pub fn send_requests_nonblocking<I>(&mut self, requests: I) -> Result<()>
where I: IntoIterator<Item = <T as Transport>::Message> + Send, I::IntoIter: Send,

This method offers a way to send data in a manner that’s identical to the raw gRPC service for ingestion-config based streaming.

pub async fn finish(self) -> Result<()>

Gracefully finish the stream, draining any remaining data before returning.

It is important to always call this method when you are done sending data and before the object is dropped.