FlowBuilder

Struct FlowBuilder 

pub struct FlowBuilder<'a, K> { /* private fields */ }
Builder to assist in constructing a flow, utilizing the flow descriptor to ensure that the flow is constructed correctly (i.e. value in the correct order and the correct data type).

By using the builder and the flow descriptor, the channel names are not necessary, which helps improve performance.

Implementations

Source

impl<K> FlowBuilder<'_, K>

pub fn request(self, now: TimeValue) -> IngestWithConfigDataStreamRequest

Builds an IngestWithConfigDataStreamRequest, consuming the builder.

Source

impl<'a, K> FlowBuilder<'a, K>
where K: Eq + Hash,

pub fn new(flow_descriptor: &'a FlowDescriptor<K>) -> Self

Initializes a new flow builder with the provided flow descriptor.

pub fn attach_run_id(&mut self, run_id: impl Into<String>)

Attaches a run ID to the flow.

pub fn set<V>(&mut self, index: ChannelIndex, value: V) -> Result<()>
where V: Into<Value>,

Sets the value of the channel with the given key.

pub fn set_with_key<Q, V>(&mut self, key: &Q, value: V) -> Result<()>
where K: Borrow<Q>, Q: Eq + Hash + ?Sized, V: Into<Value>,

Sets the value of the channel with the given key.