pub struct ChannelIndex(/* private fields */);Expand description
Represents the index of a channel in a flow.
This provides a convenient and performant way to access the value at the given channel index when building a new flow.
This type is only returned by the FlowDescriptor when adding a new channel to the
flow ensuring that the index is safe to use.