pub struct FlowBuilder<'a, K> { /* private fields */ }Expand description
Builder to assist in constructing a flow, utilizing the flow descriptor to ensure that the flow is constructed correctly (i.e. value in the correct order and the correct data type).
By using the builder and the flow descriptor, the channel names are not necessary, which helps improve performance.
Implementations
Sourceimpl<K> FlowBuilder<'_, K>
impl<K> FlowBuilder<'_, K>
Sourcepub fn request(self, now: TimeValue) -> IngestWithConfigDataStreamRequest
pub fn request(self, now: TimeValue) -> IngestWithConfigDataStreamRequest
Builds an IngestWithConfigDataStreamRequest, consuming the builder.
Sourceimpl<'a, K> FlowBuilder<'a, K>
impl<'a, K> FlowBuilder<'a, K>
Sourcepub fn new(flow_descriptor: &'a FlowDescriptor<K>) -> Self
pub fn new(flow_descriptor: &'a FlowDescriptor<K>) -> Self
Initializes a new flow builder with the provided flow descriptor.
Sourcepub fn attach_run_id(&mut self, run_id: impl Into<String>)
pub fn attach_run_id(&mut self, run_id: impl Into<String>)
Attaches a run ID to the flow.
Sourcepub fn set<V>(&mut self, index: ChannelIndex, value: V) -> Result<()>
pub fn set<V>(&mut self, index: ChannelIndex, value: V) -> Result<()>
Sets the value of the channel with the given key.