pub struct FlowDescriptor<K> { /* private fields */ }Expand description
Describes the schema of a flow, providing a convenient, performant, and correct way to build the flow being described.
The descriptor itself is immutable, to ensure that the flow is constructed correctly since successful ingestion requires Sift and the client to agree on the schema of the flow.
While the key K can be arbitrary, it is recommended to use a trivial key that avoids
allocations, such as a usize or u32, though for convenience, a string (the channel
name) could also be used and will still help minimize additional string allocations.
Example
use sift_stream::{FlowDescriptor, FlowDescriptorBuilder, FlowBuilder, ChannelDataType};
let mut flow_descriptor_builder = FlowDescriptorBuilder::new("ingestion_config_id", "my_flow_name");
let my_channel_idx = flow_descriptor_builder.add("my_channel_key", ChannelDataType::String);
let my_other_channel_idx = flow_descriptor_builder.add("my_other_channel_key", ChannelDataType::Uint64);
let flow_descriptor = flow_descriptor_builder.build();
let mut flow_builder = FlowBuilder::new(&flow_descriptor);
flow_builder.set(my_channel_idx, "my_value".to_string());
flow_builder.set_with_key("my_other_channel_key", 123_u64);Implementations
Sourceimpl<K> FlowDescriptor<K>
impl<K> FlowDescriptor<K>